Module: ActiveQueue::Adapters::ResqueAdapter
- Defined in:
- lib/active_queue/adapters/resque_adapter.rb
Defined Under Namespace
Modules: ClassMethods
Class Method Summary collapse
-
.included(base) ⇒ Object
Background jobs can be any Ruby class or module that responds to perform.
Class Method Details
.included(base) ⇒ Object
Background jobs can be any Ruby class or module that responds to perform. Your existing classes can easily be converted to background jobs or you can create new classes specifically to do work. Or, you can do both.
7 8 9 |
# File 'lib/active_queue/adapters/resque_adapter.rb', line 7 def self.included(base) base.extend(ClassMethods) end |